@@ -43,6 +43,45 @@ else:
     Span = Any
 
 
+def _get_call_stack_info(num_frames: int = 2) -> str:
+    """
+    Get the function names from the previous 1-2 functions in the call stack.
+
+    Args:
+        num_frames: Number of previous frames to include (default: 2)
+
+    Returns:
+        A string with format "current_function <- caller_function [<- grandparent_function]"
+    """
+    try:
+        current_frame = inspect.currentframe()
+        if current_frame is None:
+            return "unknown"
+
+        # Skip this function and the immediate caller (which sets call_type)
+        f_back = current_frame.f_back
+        if f_back is None:
+            return "unknown"
+        frame = f_back.f_back
+        if frame is None:
+            return "unknown"
+        function_names = []
+
+        for _ in range(num_frames):
+            if frame is None:
+                break
+            func_name = frame.f_code.co_name
+            function_names.append(func_name)
+            frame = frame.f_back
+
+        if not function_names:
+            return "unknown"
+
+        return " <- ".join(function_names)
+    except Exception:
+        return "unknown"
+
+
 class RedisCache(BaseCache):
     # if users don't provider one, use the default litellm cache
 
@@ -181,7 +220,7 @@ class RedisCache(BaseCache):
             self.service_logger_obj.service_success_hook(
                 service=ServiceTypes.REDIS,
                 duration=_duration,
-                call_type="set_cache",
+                call_type=f"set_cache <- {_get_call_stack_info()}",
                 start_time=start_time,
                 end_time=end_time,
             )
@@ -205,7 +244,7 @@ class RedisCache(BaseCache):
             self.service_logger_obj.service_success_hook(
                 service=ServiceTypes.REDIS,
                 duration=_duration,
-                call_type="increment_cache",
+                call_type=f"increment_cache <- {_get_call_stack_info()}",
                 start_time=start_time,
                 end_time=end_time,
             )
@@ -219,7 +258,7 @@ class RedisCache(BaseCache):
                 self.service_logger_obj.service_success_hook(
                     service=ServiceTypes.REDIS,
                     duration=_duration,
-                    call_type="increment_cache_ttl",
+                    call_type=f"increment_cache_ttl <- {_get_call_stack_info()}",
                     start_time=start_time,
                     end_time=end_time,
                 )
@@ -232,7 +271,7 @@ class RedisCache(BaseCache):
                     self.service_logger_obj.service_success_hook(
                         service=ServiceTypes.REDIS,
                         duration=_duration,
-                        call_type="increment_cache_expire",
+                        call_type=f"increment_cache_expire <- {_get_call_stack_info()}",
                         start_time=start_time,
                         end_time=end_time,
                     )
@@ -271,7 +310,7 @@ class RedisCache(BaseCache):
                 self.service_logger_obj.async_service_success_hook(
                     service=ServiceTypes.REDIS,
                     duration=_duration,
-                    call_type="async_scan_iter",
+                    call_type=f"async_scan_iter <- {_get_call_stack_info()}",
                     start_time=start_time,
                     end_time=end_time,
                 )
@@ -287,7 +326,7 @@ class RedisCache(BaseCache):
                     service=ServiceTypes.REDIS,
                     duration=_duration,
                     error=e,
-                    call_type="async_scan_iter",
+                    call_type=f"async_scan_iter <- {_get_call_stack_info()}",
                     start_time=start_time,
                     end_time=end_time,
                 )
@@ -341,7 +380,7 @@ class RedisCache(BaseCache):
                     start_time=start_time,
                     end_time=end_time,
                     parent_otel_span=_get_parent_otel_span_from_kwargs(kwargs),
-                    call_type="async_set_cache",
+                    call_type=f"async_set_cache <- {_get_call_stack_info()}",
                 )
             )
             verbose_logger.error(
@@ -374,7 +413,7 @@ class RedisCache(BaseCache):
                 self.service_logger_obj.async_service_success_hook(
                     service=ServiceTypes.REDIS,
                     duration=_duration,
-                    call_type="async_set_cache",
+                    call_type=f"async_set_cache <- {_get_call_stack_info()}",
                     start_time=start_time,
                     end_time=end_time,
                     parent_otel_span=_get_parent_otel_span_from_kwargs(kwargs),
@@ -390,7 +429,7 @@ class RedisCache(BaseCache):
                     service=ServiceTypes.REDIS,
                     duration=_duration,
                     error=e,
-                    call_type="async_set_cache",
+                    call_type=f"async_set_cache <- {_get_call_stack_info()}",
                     start_time=start_time,
                     end_time=end_time,
                     parent_otel_span=_get_parent_otel_span_from_kwargs(kwargs),
@@ -463,7 +502,7 @@ class RedisCache(BaseCache):
                 self.service_logger_obj.async_service_success_hook(
                     service=ServiceTypes.REDIS,
                     duration=_duration,
-                    call_type="async_set_cache_pipeline",
+                    call_type=f"async_set_cache_pipeline <- {_get_call_stack_info()}",
                     start_time=start_time,
                     end_time=end_time,
                     parent_otel_span=_get_parent_otel_span_from_kwargs(kwargs),
@@ -479,7 +518,7 @@ class RedisCache(BaseCache):
                     service=ServiceTypes.REDIS,
                     duration=_duration,
                     error=e,
-                    call_type="async_set_cache_pipeline",
+                    call_type=f"async_set_cache_pipeline <- {_get_call_stack_info()}",
                     start_time=start_time,
                     end_time=end_time,
                     parent_otel_span=_get_parent_otel_span_from_kwargs(kwargs),
@@ -528,7 +567,7 @@ class RedisCache(BaseCache):
                     start_time=start_time,
                     end_time=end_time,
                     parent_otel_span=_get_parent_otel_span_from_kwargs(kwargs),
-                    call_type="async_set_cache_sadd",
+                    call_type=f"async_set_cache_sadd <- {_get_call_stack_info()}",
                 )
             )
             # NON blocking - notify users Redis is throwing an exception
@@ -554,7 +593,7 @@ class RedisCache(BaseCache):
                 self.service_logger_obj.async_service_success_hook(
                     service=ServiceTypes.REDIS,
                     duration=_duration,
-                    call_type="async_set_cache_sadd",
+                    call_type=f"async_set_cache_sadd <- {_get_call_stack_info()}",
                     start_time=start_time,
                     end_time=end_time,
                     parent_otel_span=_get_parent_otel_span_from_kwargs(kwargs),
@@ -568,7 +607,7 @@ class RedisCache(BaseCache):
                     service=ServiceTypes.REDIS,
                     duration=_duration,
                     error=e,
-                    call_type="async_set_cache_sadd",
+                    call_type=f"async_set_cache_sadd <- {_get_call_stack_info()}",
                     start_time=start_time,
                     end_time=end_time,
                     parent_otel_span=_get_parent_otel_span_from_kwargs(kwargs),
@@ -620,7 +659,7 @@ class RedisCache(BaseCache):
                 self.service_logger_obj.async_service_success_hook(
                     service=ServiceTypes.REDIS,
                     duration=_duration,
-                    call_type="async_increment",
+                    call_type=f"async_increment <- {_get_call_stack_info()}",
                     start_time=start_time,
                     end_time=end_time,
                     parent_otel_span=parent_otel_span,
@@ -636,7 +675,7 @@ class RedisCache(BaseCache):
                     service=ServiceTypes.REDIS,
                     duration=_duration,
                     error=e,
-                    call_type="async_increment",
+                    call_type=f"async_increment <- {_get_call_stack_info()}",
                     start_time=start_time,
                     end_time=end_time,
                     parent_otel_span=parent_otel_span,
@@ -683,7 +722,7 @@ class RedisCache(BaseCache):
             self.service_logger_obj.service_success_hook(
                 service=ServiceTypes.REDIS,
                 duration=_duration,
-                call_type="get_cache",
+                call_type=f"get_cache <- {_get_call_stack_info()}",
                 start_time=start_time,
                 end_time=end_time,
                 parent_otel_span=parent_otel_span,
@@ -745,7 +784,7 @@ class RedisCache(BaseCache):
             self.service_logger_obj.service_success_hook(
                 service=ServiceTypes.REDIS,
                 duration=_duration,
-                call_type="batch_get_cache",
+                call_type=f"batch_get_cache <- {_get_call_stack_info()}",
                 start_time=start_time,
                 end_time=end_time,
                 parent_otel_span=parent_otel_span,
@@ -790,7 +829,7 @@ class RedisCache(BaseCache):
                 self.service_logger_obj.async_service_success_hook(
                     service=ServiceTypes.REDIS,
                     duration=_duration,
-                    call_type="async_get_cache",
+                    call_type=f"async_get_cache <- {_get_call_stack_info()}",
                     start_time=start_time,
                     end_time=end_time,
                     parent_otel_span=parent_otel_span,
@@ -806,7 +845,7 @@ class RedisCache(BaseCache):
                     service=ServiceTypes.REDIS,
                     duration=_duration,
                     error=e,
-                    call_type="async_get_cache",
+                    call_type=f"async_get_cache <- {_get_call_stack_info()}",
                     start_time=start_time,
                     end_time=end_time,
                     parent_otel_span=parent_otel_span,
@@ -851,7 +890,7 @@ class RedisCache(BaseCache):
                 self.service_logger_obj.async_service_success_hook(
                     service=ServiceTypes.REDIS,
                     duration=_duration,
-                    call_type="async_batch_get_cache",
+                    call_type=f"async_batch_get_cache <- {_get_call_stack_info()}",
                     start_time=start_time,
                     end_time=end_time,
                     parent_otel_span=parent_otel_span,
@@ -879,7 +918,7 @@ class RedisCache(BaseCache):
                     service=ServiceTypes.REDIS,
                     duration=_duration,
                     error=e,
-                    call_type="async_batch_get_cache",
+                    call_type=f"async_batch_get_cache <- {_get_call_stack_info()}",
                     start_time=start_time,
                     end_time=end_time,
                     parent_otel_span=parent_otel_span,
@@ -903,7 +942,7 @@ class RedisCache(BaseCache):
             self.service_logger_obj.service_success_hook(
                 service=ServiceTypes.REDIS,
                 duration=_duration,
-                call_type="sync_ping",
+                call_type=f"sync_ping <- {_get_call_stack_info()}",
                 start_time=start_time,
                 end_time=end_time,
             )
@@ -917,7 +956,7 @@ class RedisCache(BaseCache):
                 service=ServiceTypes.REDIS,
                 duration=_duration,
                 error=e,
-                call_type="sync_ping",
+                call_type=f"sync_ping <- {_get_call_stack_info()}",
             )
             verbose_logger.error(
                 f"LiteLLM Redis Cache PING: - Got exception from REDIS : {str(e)}"
@@ -938,7 +977,7 @@ class RedisCache(BaseCache):
                 self.service_logger_obj.async_service_success_hook(
                     service=ServiceTypes.REDIS,
                     duration=_duration,
-                    call_type="async_ping",
+                    call_type=f"async_ping <- {_get_call_stack_info()}",
                 )
             )
             return response
@@ -952,7 +991,7 @@ class RedisCache(BaseCache):
                     service=ServiceTypes.REDIS,
                     duration=_duration,
                     error=e,
-                    call_type="async_ping",
+                    call_type=f"async_ping <- {_get_call_stack_info()}",
                 )
             )
             verbose_logger.error(
@@ -1051,7 +1090,7 @@ class RedisCache(BaseCache):
                 self.service_logger_obj.async_service_success_hook(
                     service=ServiceTypes.REDIS,
                     duration=_duration,
-                    call_type="async_increment_pipeline",
+                    call_type=f"async_increment_pipeline <- {_get_call_stack_info()}",
                     start_time=start_time,
                     end_time=end_time,
                     parent_otel_span=_get_parent_otel_span_from_kwargs(kwargs),
@@ -1067,7 +1106,7 @@ class RedisCache(BaseCache):
                     service=ServiceTypes.REDIS,
                     duration=_duration,
                     error=e,
-                    call_type="async_increment_pipeline",
+                    call_type=f"async_increment_pipeline <- {_get_call_stack_info()}",
                     start_time=start_time,
                     end_time=end_time,
                     parent_otel_span=_get_parent_otel_span_from_kwargs(kwargs),
@@ -1131,7 +1170,7 @@ class RedisCache(BaseCache):
                 self.service_logger_obj.async_service_success_hook(
                     service=ServiceTypes.REDIS,
                     duration=_duration,
-                    call_type="async_rpush",
+                    call_type=f"async_rpush <- {_get_call_stack_info()}",
                 )
             )
             return response
@@ -1145,7 +1184,7 @@ class RedisCache(BaseCache):
                     service=ServiceTypes.REDIS,
                     duration=_duration,
                     error=e,
-                    call_type="async_rpush",
+                    call_type=f"async_rpush <- {_get_call_stack_info()}",
                 )
             )
             verbose_logger.error(
@@ -1202,7 +1241,7 @@ class RedisCache(BaseCache):
                 self.service_logger_obj.async_service_success_hook(
                     service=ServiceTypes.REDIS,
                     duration=_duration,
-                    call_type="async_lpop",
+                    call_type=f"async_lpop <- {_get_call_stack_info()}",
                 )
             )
 
@@ -1230,7 +1269,7 @@ class RedisCache(BaseCache):
                     service=ServiceTypes.REDIS,
                     duration=_duration,
                     error=e,
-                    call_type="async_lpop",
+                    call_type=f"async_lpop <- {_get_call_stack_info()}",
                 )
             )
             verbose_logger.error(
