@@ -8,6 +8,9 @@ Example:
     "prometheus" -> PrometheusLogger
 """
 
+from typing import Union
+
+from litellm import _custom_logger_compatible_callbacks_literal
 from litellm.integrations.agentops import AgentOps
 from litellm.integrations.anthropic_cache_control_hook import AnthropicCacheControlHook
 from litellm.integrations.argilla import ArgillaLogger
@@ -30,11 +33,16 @@ from litellm.integrations.mlflow import MlflowLogger
 from litellm.integrations.openmeter import OpenMeterLogger
 from litellm.integrations.opentelemetry import OpenTelemetry
 from litellm.integrations.opik.opik import OpikLogger
-from litellm.integrations.prometheus import PrometheusLogger
+
+try:
+    from litellm_enterprise.integrations.prometheus import PrometheusLogger
+except Exception:
+    PrometheusLogger = None
+from litellm.integrations.dotprompt import DotpromptManager
 from litellm.integrations.s3_v2 import S3Logger
 from litellm.integrations.sqs import SQSLogger
-from litellm.integrations.vector_store_integrations.bedrock_vector_store import (
-    BedrockVectorStore,
+from litellm.integrations.vector_store_integrations.vector_store_pre_call_hook import (
+    VectorStorePreCallHook,
 )
 from litellm.proxy.hooks.dynamic_rate_limiter import _PROXY_DynamicRateLimitHandler
 
@@ -43,6 +51,7 @@ class CustomLoggerRegistry:
     """
     Registry mapping the callback class string to the class type.
     """
+
     CALLBACK_CLASS_STR_TO_CLASS_TYPE = {
         "lago": LagoLogger,
         "openmeter": OpenMeterLogger,
@@ -71,11 +80,12 @@ class CustomLoggerRegistry:
         "gcs_pubsub": GcsPubSubLogger,
         "anthropic_cache_control_hook": AnthropicCacheControlHook,
         "agentops": AgentOps,
-        "bedrock_vector_store": BedrockVectorStore,
         "deepeval": DeepEvalLogger,
         "s3_v2": S3Logger,
         "aws_sqs": SQSLogger,
         "dynamic_rate_limiter": _PROXY_DynamicRateLimitHandler,
+        "vector_store_pre_call_hook": VectorStorePreCallHook,
+        "dotprompt": DotpromptManager,
     }
 
     try:
@@ -103,17 +113,20 @@ class CustomLoggerRegistry:
         pass  # enterprise not installed
 
     @classmethod
-    def get_callback_str_from_class_type(cls, class_type: type) -> str | None:
+    def get_callback_str_from_class_type(cls, class_type: type) -> Union[str, None]:
         """
         Get the callback string from the class type.
-        
+
         Args:
             class_type: The class type to find the string for
-            
+
         Returns:
             str: The callback string, or None if not found
         """
-        for callback_str, callback_class in cls.CALLBACK_CLASS_STR_TO_CLASS_TYPE.items():
+        for (
+            callback_str,
+            callback_class,
+        ) in cls.CALLBACK_CLASS_STR_TO_CLASS_TYPE.items():
             if callback_class == class_type:
                 return callback_str
         return None
@@ -123,15 +136,29 @@ class CustomLoggerRegistry:
         """
         Get all callback strings that map to the same class type.
         Some class types (like OpenTelemetry) have multiple string mappings.
-        
+
         Args:
             class_type: The class type to find all strings for
-            
+
         Returns:
             list: List of callback strings that map to the class type
         """
         callback_strs: list[str] = []
-        for callback_str, callback_class in cls.CALLBACK_CLASS_STR_TO_CLASS_TYPE.items():
+        for (
+            callback_str,
+            callback_class,
+        ) in cls.CALLBACK_CLASS_STR_TO_CLASS_TYPE.items():
             if callback_class == class_type:
                 callback_strs.append(callback_str)
-        return callback_strs
\ No newline at end of file
+        return callback_strs
+    
+
+    @classmethod
+    def get_class_type_for_custom_logger_name(
+        cls,
+        custom_logger_name: _custom_logger_compatible_callbacks_literal,
+    ) -> type:
+        """
+        Get the class type for a given custom logger name
+        """
+        return cls.CALLBACK_CLASS_STR_TO_CLASS_TYPE[custom_logger_name]
