@@ -351,11 +351,18 @@ def get_llm_provider(  # noqa: PLR0915
             custom_llm_provider = "openai"
         elif model in litellm.empower_models:
             custom_llm_provider = "empower"
+        elif model in litellm.gradient_ai_models:
+            custom_llm_provider = "gradient_ai"
         elif model == "*":
             custom_llm_provider = "openai"
         # bytez models
         elif model.startswith("bytez/"):
             custom_llm_provider = "bytez"
+        # cometapi models
+        elif model.startswith("cometapi/"):
+            custom_llm_provider = "cometapi"
+        elif model.startswith("oci/"):
+            custom_llm_provider = "oci"
         if not custom_llm_provider:
             if litellm.suppress_debug_info is False:
                 print()  # noqa
@@ -662,6 +669,13 @@ def _get_openai_compatible_provider_info(  # noqa: PLR0915
             or f"https://{get_secret('SNOWFLAKE_ACCOUNT_ID')}.snowflakecomputing.com/api/v2/cortex/inference:complete"
         )  # type: ignore
         dynamic_api_key = api_key or get_secret_str("SNOWFLAKE_JWT")
+    elif custom_llm_provider == "gradient_ai":
+        (
+            api_base,
+            dynamic_api_key,
+        ) = litellm.GradientAIConfig()._get_openai_compatible_provider_info(
+            api_base, api_key
+        )
     elif custom_llm_provider == "featherless_ai":
         (
             api_base,
