@@ -519,23 +519,25 @@ def unpack_defs(schema: dict, defs: dict) -> None:
     }
 
     # Use iterative approach with queue to avoid recursion
-    # Each item in queue is (node, parent_container, key/index, active_defs, seen_ids)
-    queue: deque[tuple[Any, Union[dict, list, None], Union[str, int, None], dict, set]] = deque([(schema, None, None, root_defs, set())])
-    
+    # Each item in queue is (node, parent_container, key/index, active_defs, ref_chain)
+    queue: deque[
+        tuple[Any, Union[dict, list, None], Union[str, int, None], dict, set]
+    ] = deque([(schema, None, None, root_defs, set())])
+
     while queue:
-        node, parent, key, active_defs, seen = queue.popleft()
-        
-        # Avoid infinite loops on self-referential schemas
-        if id(node) in seen:
-            continue
-        seen = seen.copy()  # Create new set for this branch
-        seen.add(id(node))
+        node, parent, key, active_defs, ref_chain = queue.popleft()
 
         # ----------------------------- dict -----------------------------
         if isinstance(node, dict):
             # --- Case 1: this node *is* a reference ---
             if "$ref" in node:
                 ref_name = node["$ref"].split("/")[-1]
+
+                # Check for circular reference in the resolution chain
+                if ref_name in ref_chain:
+                    # Circular reference detected - leave as-is to prevent infinite recursion
+                    continue
+
                 target_schema = active_defs.get(ref_name)
                 # Unknown reference – leave untouched
                 if target_schema is None:
@@ -560,9 +562,13 @@ def unpack_defs(schema: dict, defs: dict) -> None:
                     schema.clear()
                     schema.update(resolved)
                     resolved = schema
-                
+
+                # Add to ref chain to track circular references
+                new_ref_chain = ref_chain.copy()
+                new_ref_chain.add(ref_name)
+
                 # Add resolved node to queue for further processing
-                queue.append((resolved, parent, key, child_defs, seen))
+                queue.append((resolved, parent, key, child_defs, new_ref_chain))
                 continue
 
             # --- Case 2: regular dict – process its values ---
@@ -575,13 +581,13 @@ def unpack_defs(schema: dict, defs: dict) -> None:
 
             # Add all dict values to queue
             for k, v in node.items():
-                queue.append((v, node, k, current_defs, seen))
+                queue.append((v, node, k, current_defs, ref_chain))
 
         # ---------------------------- list ------------------------------
         elif isinstance(node, list):
             # Add all list items to queue
             for idx, item in enumerate(node):
-                queue.append((item, node, idx, active_defs, seen))
+                queue.append((item, node, idx, active_defs, ref_chain))
 
 
 def _get_image_mime_type_from_url(url: str) -> Optional[str]:
@@ -750,3 +756,111 @@ def migrate_file_to_image_url(
     if format and isinstance(image_url_object["image_url"], dict):
         image_url_object["image_url"]["format"] = format
     return image_url_object
+
+
+def get_last_user_message(messages: List[AllMessageValues]) -> Optional[str]:
+    """
+    Get the last consecutive block of messages from the user.
+
+    Example:
+    messages = [
+        {"role": "user", "content": "Hello, how are you?"},
+        {"role": "assistant", "content": "I'm good, thank you!"},
+        {"role": "user", "content": "What is the weather in Tokyo?"},
+    ]
+    get_user_prompt(messages) -> "What is the weather in Tokyo?"
+    """
+    from litellm.litellm_core_utils.prompt_templates.common_utils import (
+        convert_content_list_to_str,
+    )
+
+    if not messages:
+        return None
+
+    # Iterate from the end to find the last consecutive block of user messages
+    user_messages = []
+    for message in reversed(messages):
+        if message.get("role") == "user":
+            user_messages.append(message)
+        else:
+            # Stop when we hit a non-user message
+            break
+
+    if not user_messages:
+        return None
+
+    # Reverse to get the messages in chronological order
+    user_messages.reverse()
+
+    user_prompt = ""
+    for message in user_messages:
+        text_content = convert_content_list_to_str(message)
+        user_prompt += text_content + "\n"
+
+    result = user_prompt.strip()
+    return result if result else None
+
+
+def set_last_user_message(
+    messages: List[AllMessageValues], content: str
+) -> List[AllMessageValues]:
+    """
+    Set the last user message
+
+    1. remove all the last consecutive user messages (FROM THE END)
+    2. add the new message
+    """
+    idx_to_remove = []
+    for idx, message in enumerate(reversed(messages)):
+        if message.get("role") == "user":
+            idx_to_remove.append(idx)
+        else:
+            # Stop when we hit a non-user message
+            break
+    if idx_to_remove:
+        messages = [
+            message
+            for idx, message in enumerate(reversed(messages))
+            if idx not in idx_to_remove
+        ]
+        messages.reverse()
+    messages.append({"role": "user", "content": content})
+    return messages
+
+
+def convert_prefix_message_to_non_prefix_messages(
+    messages: List[AllMessageValues],
+) -> List[AllMessageValues]:
+    """
+    For models that don't support {prefix: true} in messages, we need to convert the prefix message to a non-prefix message.
+
+    Use prompt:
+
+    {"role": "assistant", "content": "value", "prefix": true} -> [
+        {
+            "role": "system",
+            "content": "You are a helpful assistant. You are given a message and you need to respond to it. You are also given a generated content. You need to respond to the message in continuation of the generated content. Do not repeat the same content. Your response should be in continuation of this text: ",
+        },
+        {
+            "role": "assistant",
+            "content": message["content"],
+        },
+    ]
+
+    do this in place
+    """
+    new_messages: List[AllMessageValues] = []
+    for message in messages:
+        if message.get("prefix"):
+            new_messages.append(
+                {
+                    "role": "system",
+                    "content": "You are a helpful assistant. You are given a message and you need to respond to it. You are also given a generated content. You need to respond to the message in continuation of the generated content. Do not repeat the same content. Your response should be in continuation of this text: ",
+                }
+            )
+            new_messages.append(
+                {**{k: v for k, v in message.items() if k != "prefix"}}  # type: ignore
+            )
+        else:
+            new_messages.append(message)
+    return new_messages
