@@ -662,6 +662,11 @@ class BaseAzureLLM(BaseOpenAILLM):
         headers: dict,  litellm_params: Optional[GenericLiteLLMParams]
     ) -> dict:
         litellm_params = litellm_params or GenericLiteLLMParams()
+        
+        # If api-key is already in headers, preserve it
+        if "api-key" in headers:
+            return headers
+            
         api_key = (
             litellm_params.api_key
             or litellm.api_key
