@@ -156,28 +156,23 @@ class BedrockEmbedding(BaseAWSLLM):
         aws_region_name: str,
         model: str,
         logging_obj: Any,
+        api_key: Optional[str] = None,
     ):
-        try:
-            from botocore.auth import SigV4Auth
-            from botocore.awsrequest import AWSRequest
-        except ImportError:
-            raise ImportError("Missing boto3 to call bedrock. Run 'pip install boto3'.")
-
         responses: List[dict] = []
         for data in batch_data:
-            sigv4 = SigV4Auth(credentials, "bedrock", aws_region_name)
             headers = {"Content-Type": "application/json"}
             if extra_headers is not None:
                 headers = {"Content-Type": "application/json", **extra_headers}
-            request = AWSRequest(
-                method="POST", url=endpoint_url, data=json.dumps(data), headers=headers
-            )
-            sigv4.add_auth(request)
-            if (
-                extra_headers is not None and "Authorization" in extra_headers
-            ):  # prevent sigv4 from overwriting the auth header
-                request.headers["Authorization"] = extra_headers["Authorization"]
-            prepped = request.prepare()
+                
+            prepped = self.get_request_headers(
+                 credentials=credentials,
+                 aws_region_name=aws_region_name,
+                 extra_headers=extra_headers,
+                 endpoint_url=endpoint_url,
+                 data=json.dumps(data),
+                 headers=headers,
+                 api_key=api_key
+             )
 
             ## LOGGING
             logging_obj.pre_call(
@@ -245,28 +240,23 @@ class BedrockEmbedding(BaseAWSLLM):
         aws_region_name: str,
         model: str,
         logging_obj: Any,
+        api_key: Optional[str] = None,
     ):
-        try:
-            from botocore.auth import SigV4Auth
-            from botocore.awsrequest import AWSRequest
-        except ImportError:
-            raise ImportError("Missing boto3 to call bedrock. Run 'pip install boto3'.")
-
         responses: List[dict] = []
         for data in batch_data:
-            sigv4 = SigV4Auth(credentials, "bedrock", aws_region_name)
             headers = {"Content-Type": "application/json"}
             if extra_headers is not None:
                 headers = {"Content-Type": "application/json", **extra_headers}
-            request = AWSRequest(
-                method="POST", url=endpoint_url, data=json.dumps(data), headers=headers
-            )
-            sigv4.add_auth(request)
-            if (
-                extra_headers is not None and "Authorization" in extra_headers
-            ):  # prevent sigv4 from overwriting the auth header
-                request.headers["Authorization"] = extra_headers["Authorization"]
-            prepped = request.prepare()
+                
+            prepped = self.get_request_headers(
+                 credentials=credentials,
+                 aws_region_name=aws_region_name,
+                 extra_headers=extra_headers,
+                 endpoint_url=endpoint_url,
+                 data=json.dumps(data),
+                 headers=headers,
+                 api_key=api_key,
+             )
 
             ## LOGGING
             logging_obj.pre_call(
@@ -338,13 +328,8 @@ class BedrockEmbedding(BaseAWSLLM):
         extra_headers: Optional[dict],
         optional_params: dict,
         litellm_params: dict,
+        api_key: Optional[str] = None,
     ) -> EmbeddingResponse:
-        try:
-            from botocore.auth import SigV4Auth
-            from botocore.awsrequest import AWSRequest
-        except ImportError:
-            raise ImportError("Missing boto3 to call bedrock. Run 'pip install boto3'.")
-
         credentials, aws_region_name = self._load_credentials(optional_params)
 
         ### TRANSFORMATION ###
@@ -428,6 +413,7 @@ class BedrockEmbedding(BaseAWSLLM):
                     aws_region_name=aws_region_name,
                     model=model,
                     logging_obj=logging_obj,
+                    api_key=api_key,
                 )
             return self._single_func_embeddings(
                 client=(
@@ -443,24 +429,24 @@ class BedrockEmbedding(BaseAWSLLM):
                 aws_region_name=aws_region_name,
                 model=model,
                 logging_obj=logging_obj,
+                api_key=api_key,
             )
         elif data is None:
             raise Exception("Unable to map Bedrock request to provider")
 
-        sigv4 = SigV4Auth(credentials, "bedrock", aws_region_name)
         headers = {"Content-Type": "application/json"}
         if extra_headers is not None:
             headers = {"Content-Type": "application/json", **extra_headers}
-
-        request = AWSRequest(
-            method="POST", url=endpoint_url, data=json.dumps(data), headers=headers
+        
+        prepped = self.get_request_headers(
+            credentials=credentials,
+            aws_region_name=aws_region_name,
+            extra_headers=extra_headers,
+            endpoint_url=endpoint_url,
+            data=json.dumps(data),
+            headers=headers,
+            api_key=api_key,
         )
-        sigv4.add_auth(request)
-        if (
-            extra_headers is not None and "Authorization" in extra_headers
-        ):  # prevent sigv4 from overwriting the auth header
-            request.headers["Authorization"] = extra_headers["Authorization"]
-        prepped = request.prepare()
 
         ## ROUTING ##
         return cohere_embedding(
