@@ -324,7 +324,7 @@ def _convert_health_check_to_dict(check) -> dict:
 def _check_prisma_client():
     """Helper to check if prisma_client is available and raise appropriate error"""
     from litellm.proxy.proxy_server import prisma_client
-    
+
     if prisma_client is None:
         raise HTTPException(
             status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
@@ -334,23 +334,23 @@ def _check_prisma_client():
 
 
 async def _save_health_check_to_db(
-    prisma_client, 
-    model_name: str, 
-    healthy_endpoints: list, 
-    unhealthy_endpoints: list, 
-    start_time: float, 
+    prisma_client,
+    model_name: str,
+    healthy_endpoints: list,
+    unhealthy_endpoints: list,
+    start_time: float,
     user_id: Optional[str],
-    model_id: Optional[str] = None
+    model_id: Optional[str] = None,
 ):
     """Helper function to save health check results to database"""
     try:
         # Extract error message from first unhealthy endpoint if available
         error_message = (
-            str(unhealthy_endpoints[0]["error"])[:500] 
-            if unhealthy_endpoints and unhealthy_endpoints[0].get("error") 
+            str(unhealthy_endpoints[0]["error"])[:500]
+            if unhealthy_endpoints and unhealthy_endpoints[0].get("error")
             else None
         )
-        
+
         await prisma_client.save_health_check_result(
             model_name=model_name,
             model_id=model_id,
@@ -363,7 +363,9 @@ async def _save_health_check_to_db(
             checked_by=user_id,
         )
     except Exception as db_error:
-        verbose_proxy_logger.warning(f"Failed to save health check to database for model {model_name}: {db_error}")
+        verbose_proxy_logger.warning(
+            f"Failed to save health check to database for model {model_name}: {db_error}"
+        )
         # Continue execution - don't let database save failure break health checks
 
 
@@ -375,31 +377,30 @@ async def _perform_health_check_and_save(
     prisma_client,
     start_time,
     user_id,
-    model_id=None
+    model_id=None,
 ):
     """Helper function to perform health check and save results to database"""
     healthy_endpoints, unhealthy_endpoints = await perform_health_check(
-        model_list=model_list, 
-        cli_model=cli_model, 
-        model=target_model,
-        details=details
+        model_list=model_list, cli_model=cli_model, model=target_model, details=details
     )
-    
+
     # Optionally save health check result to database (non-blocking)
     if prisma_client is not None:
         # For CLI model, use cli_model name; for router models, use target_model
         model_name_for_db = cli_model if cli_model is not None else target_model
         if model_name_for_db is not None:
-            asyncio.create_task(_save_health_check_to_db(
-                prisma_client,
-                model_name_for_db,
-                healthy_endpoints,
-                unhealthy_endpoints,
-                start_time,
-                user_id,
-                model_id=model_id
-            ))
-    
+            asyncio.create_task(
+                _save_health_check_to_db(
+                    prisma_client,
+                    model_name_for_db,
+                    healthy_endpoints,
+                    unhealthy_endpoints,
+                    start_time,
+                    user_id,
+                    model_id=model_id,
+                )
+            )
+
     return {
         "healthy_endpoints": healthy_endpoints,
         "unhealthy_endpoints": unhealthy_endpoints,
@@ -434,19 +435,20 @@ async def health_endpoint(
     ```
     else, the health checks will be run on models when /health is called.
     """
+    import time
+
     from litellm.proxy.proxy_server import (
         health_check_details,
         health_check_results,
         llm_model_list,
         llm_router,
+        prisma_client,
         use_background_health_checks,
         user_model,
-        prisma_client,
     )
-    import time
 
     start_time = time.time()
-    
+
     # Handle model_id parameter - convert to model name for health check
     target_model = model
     if model_id and not model:
@@ -462,7 +464,9 @@ async def health_endpoint(
                         detail={"error": f"Model with ID {model_id} not found"},
                     )
             except Exception as e:
-                verbose_proxy_logger.error(f"Error getting deployment for model_id {model_id}: {e}")
+                verbose_proxy_logger.error(
+                    f"Error getting deployment for model_id {model_id}: {e}"
+                )
                 raise HTTPException(
                     status_code=status.HTTP_404_NOT_FOUND,
                     detail={"error": f"Model with ID {model_id} not found"},
@@ -472,7 +476,7 @@ async def health_endpoint(
                 status_code=status.HTTP_404_NOT_FOUND,
                 detail={"error": f"Model with ID {model_id} not found"},
             )
-    
+
     try:
         if llm_model_list is None:
             # if no router set, check if user set a model using litellm --model ollama/llama2
@@ -485,7 +489,7 @@ async def health_endpoint(
                     prisma_client=prisma_client,
                     start_time=start_time,
                     user_id=user_api_key_dict.user_id,
-                    model_id=None  # CLI model doesn't have model_id
+                    model_id=None,  # CLI model doesn't have model_id
                 )
             raise HTTPException(
                 status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
@@ -508,7 +512,7 @@ async def health_endpoint(
                 prisma_client=prisma_client,
                 start_time=start_time,
                 user_id=user_api_key_dict.user_id,
-                model_id=model_id
+                model_id=model_id,
             )
     except Exception as e:
         verbose_proxy_logger.error(
@@ -520,7 +524,9 @@ async def health_endpoint(
         raise e
 
 
-@router.get("/health/history", tags=["health"], dependencies=[Depends(user_api_key_auth)])
+@router.get(
+    "/health/history", tags=["health"], dependencies=[Depends(user_api_key_auth)]
+)
 async def health_check_history_endpoint(
     user_api_key_dict: UserAPIKeyAuth = Depends(user_api_key_auth),
     model: Optional[str] = fastapi.Query(
@@ -532,17 +538,15 @@ async def health_check_history_endpoint(
     limit: int = fastapi.Query(
         100, description="Number of records to return", ge=1, le=1000
     ),
-    offset: int = fastapi.Query(
-        0, description="Number of records to skip", ge=0
-    ),
+    offset: int = fastapi.Query(0, description="Number of records to skip", ge=0),
 ):
     """
     Get health check history for models
-    
+
     Returns historical health check data with optional filtering.
     """
     prisma_client = _check_prisma_client()
-    
+
     try:
         history = await prisma_client.get_health_check_history(
             model_name=model,
@@ -550,10 +554,10 @@ async def health_check_history_endpoint(
             offset=offset,
             status_filter=status_filter,
         )
-        
+
         # Convert to dict format for JSON response using helper function
         history_data = [_convert_health_check_to_dict(check) for check in history]
-        
+
         return {
             "health_checks": history_data,
             "total_records": len(history_data),
@@ -568,26 +572,30 @@ async def health_check_history_endpoint(
         )
 
 
-@router.get("/health/latest", tags=["health"], dependencies=[Depends(user_api_key_auth)])
+@router.get(
+    "/health/latest", tags=["health"], dependencies=[Depends(user_api_key_auth)]
+)
 async def latest_health_checks_endpoint(
     user_api_key_dict: UserAPIKeyAuth = Depends(user_api_key_auth),
 ):
     """
     Get the latest health check status for all models
-    
+
     Returns the most recent health check result for each model.
     """
     prisma_client = _check_prisma_client()
-    
+
     try:
         latest_checks = await prisma_client.get_all_latest_health_checks()
-        
+
         # Convert to dict format for JSON response using helper function
         checks_data = {
-            (check.model_id if check.model_id else check.model_name): _convert_health_check_to_dict(check)
+            (
+                check.model_id if check.model_id else check.model_name
+            ): _convert_health_check_to_dict(check)
             for check in latest_checks
         }
-        
+
         return {
             "latest_health_checks": checks_data,
             "total_models": len(checks_data),
@@ -896,6 +904,7 @@ async def test_model_connection(
             litellm_params=litellm_params,
         )
         mode = mode or litellm_params.pop("mode", None)
+
         result = await run_with_timeout(
             litellm.ahealth_check(
                 model_params=litellm_params,
