@@ -272,6 +272,16 @@ class LiteLLMProxyRequestSetup:
             return float(timeout_header)
         return None
 
+    @staticmethod
+    def _get_num_retries_from_request(headers: dict) -> Optional[int]:
+        """
+        Workaround for client request from Vercel's AI SDK.
+        """
+        num_retries_header = headers.get("x-litellm-num-retries", None)
+        if num_retries_header is not None:
+            return int(num_retries_header)
+        return None
+
     @staticmethod
     def _get_forwardable_headers(
         headers: Union[Headers, dict],
@@ -407,6 +417,10 @@ class LiteLLMProxyRequestSetup:
         if timeout is not None:
             data["timeout"] = timeout
 
+        num_retries = LiteLLMProxyRequestSetup._get_num_retries_from_request(headers)
+        if num_retries is not None:
+            data["num_retries"] = num_retries
+
         return data
 
     @staticmethod
@@ -425,6 +439,32 @@ class LiteLLMProxyRequestSetup:
             user_api_key_request_route=user_api_key_dict.request_route,
         )
         return user_api_key_logged_metadata
+    
+    @staticmethod
+    def add_user_api_key_auth_to_request_metadata(
+        data: dict,
+        user_api_key_dict: UserAPIKeyAuth,
+        _metadata_variable_name: str,
+    ) -> dict:
+        """
+        Adds the `UserAPIKeyAuth` object to the request metadata.
+        """
+        user_api_key_logged_metadata = (
+            LiteLLMProxyRequestSetup.get_sanitized_user_information_from_key(
+                user_api_key_dict=user_api_key_dict
+            )
+        )
+        data[_metadata_variable_name].update(user_api_key_logged_metadata)
+        data[_metadata_variable_name][
+            "user_api_key"
+        ] = (
+            user_api_key_dict.api_key
+        )  # this is just the hashed token
+
+        data[_metadata_variable_name]["user_api_end_user_max_budget"] = getattr(
+            user_api_key_dict, "end_user_max_budget", None
+        )
+        return data
 
     @staticmethod
     def add_key_level_controls(
@@ -563,6 +603,7 @@ async def add_litellm_data_to_request(  # noqa: PLR0915
     """
 
     from litellm.proxy.proxy_server import llm_router, premium_user
+    from litellm.types.proxy.litellm_pre_call_utils import SecretFields
 
     safe_add_api_version_from_query_params(data, request)
 
@@ -599,6 +640,8 @@ async def add_litellm_data_to_request(  # noqa: PLR0915
         "body": copy.copy(data),  # use copy instead of deepcopy
     }
 
+    data["secret_fields"] = SecretFields(raw_headers=dict(request.headers))
+
     ## Dynamic api version (Azure OpenAI endpoints) ##
     try:
         query_params = request.query_params
@@ -643,22 +686,11 @@ async def add_litellm_data_to_request(  # noqa: PLR0915
             data["metadata"]
         )
 
-    user_api_key_logged_metadata = (
-        LiteLLMProxyRequestSetup.get_sanitized_user_information_from_key(
-            user_api_key_dict=user_api_key_dict
-        )
+    data = LiteLLMProxyRequestSetup.add_user_api_key_auth_to_request_metadata(
+        data=data,
+        user_api_key_dict=user_api_key_dict,
+        _metadata_variable_name=_metadata_variable_name,
     )
-    data[_metadata_variable_name].update(user_api_key_logged_metadata)
-    data[_metadata_variable_name][
-        "user_api_key"
-    ] = (
-        user_api_key_dict.api_key
-    )  # this is just the hashed token. [TODO]: replace variable name in repo.
-
-    data[_metadata_variable_name]["user_api_end_user_max_budget"] = getattr(
-        user_api_key_dict, "end_user_max_budget", None
-    )
-
     data[_metadata_variable_name]["litellm_api_version"] = version
 
     if general_settings is not None:
@@ -782,6 +814,15 @@ async def add_litellm_data_to_request(  # noqa: PLR0915
             for k, v in callback_settings_obj.callback_vars.items():
                 data[k] = v
 
+    # Add disabled callbacks from key metadata
+    if (
+        user_api_key_dict.metadata
+        and "litellm_disabled_callbacks" in user_api_key_dict.metadata
+    ):
+        disabled_callbacks = user_api_key_dict.metadata["litellm_disabled_callbacks"]
+        if disabled_callbacks and isinstance(disabled_callbacks, list):
+            data["litellm_disabled_callbacks"] = disabled_callbacks
+
     # Guardrails
     move_guardrails_to_metadata(
         data=data,
